# Changelog
All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.1.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [Unreleased]

## [0.2.0] - 2022-04-01
### Added
- Added get_destination_path_for_repo function
- Added .editorconfig

## [0.1.3] - 2022-03-31
### Fixed
- Add py.typed file to package to enable type info

## [0.1.2] - 2022-03-31
### Fixed
- Update to typer 0.4.1 which allows click requirement to be loosened again

## [0.1.1] - 2022-03-30
### Fixed
- Link to README in PyPI entry
- Update pyproject.toml with links

## [0.1.0] - 2022-03-30
### Added
- Starting a changelog using [changelog-manager](https://github.com/axelfauvel/changelog-manager)
- Added [just](https://github.com/casey/just) justfile for building
- Added [asdf](https://asdf-vm.com) .tool-versions

## [0.0.0] - 2022-03-24
### Added
- Imported my code
